@@ -2,9 +2,10 @@ import logging
 import os
 from dataclasses import dataclass
 from time import sleep
-from typing import Any, Dict, Optional
+from typing import Any, Dict, List, Optional
 
 import httpx
+from pydantic import parse_obj_as
 
 from . import __version__, api, exceptions
 
@@ -290,3 +291,23 @@ class APIClient:
         response = self._api_request(url=url)
         response_object = api.TokenBalance.Response.parse_obj(response)
         return response_object
+
+    def token_get_messages(self, token: str) -> List[api.TokenMessage]:
+        """Get messages for/from the token."""
+        url = self.api_endpoint + f"/token/{token}/messages"
+        log.debug(f"Token send message URL: {url}")
+        response = self._httpx_client.get(url=url)
+        if response.status_code == 422:
+            raise exceptions.SporeStackUserError(response.json()["detail"])
+        response.raise_for_status()
+
+        return parse_obj_as(List[api.TokenMessage], response.json())
+
+    def token_send_message(self, token: str, message: str) -> None:
+        """Send a message to SporeStack support."""
+        url = self.api_endpoint + f"/token/{token}/messages"
+        response = self._httpx_client.post(url=url, json={"message": message})
+        if response.status_code == 422:
+            raise exceptions.SporeStackUserError(response.json()["detail"])
+
+        response.raise_for_status()
