@@ -64,6 +64,14 @@ class Token:
         """Returns the token's balance in cents."""
         return self.api_client.token_balance(token=self.token).cents
 
+    def messages(self) -> List[api.TokenMessage]:
+        """Returns support messages for/from the token."""
+        return self.api_client.token_get_messages(token=self.token)
+
+    def send_message(self, message: str) -> None:
+        """Returns support messages for/from the token."""
+        self.api_client.token_send_message(token=self.token, message=message)
+
     def servers(self) -> List[Server]:
         server_classes: List[Server] = []
         for server in self.api_client.servers_launched_from_token(self.token).servers:
